==========
medimtools
==========

A python package containing all the tools you might ever need (allegedly) for medical imaging

.. image:: https://img.shields.io/pypi/v/medimtools.svg
        :target: https://pypi.python.org/pypi/medimtools

.. image:: https://github.com/surajpaib/medimtools/actions/workflows/python-publish.yml/badge.svg
        :target: https://github.com/surajpaib/medimtools/actions/workflows/python-publish.yml

.. image:: https://readthedocs.org/projects/medimtools/badge/?version=latest
        :target: https://medimtools.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status


* Free software: MIT license
* Documentation: https://medimtools.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
